# pack materials and molecules

[![Python versions][python-badge]][python-link]
[![Build Status][ci-badge]][ci-link]
[![Coverage Status][cov-badge]][cov-link]
[![License][license-badge]][license-link]

[python-badge]: https://img.shields.io/pypi/pyversions/pack-mm.svg
[python-link]: https://pypi.org/project/pack-mm/
[ci-badge]: https://github.com/ddmms/pack-mm/actions/workflows/build.yml/badge.svg?branch=main
[ci-link]: https://github.com/ddmms/pack-mm/actions
[cov-badge]: https://coveralls.io/repos/github/ddmms/pack-mm/badge.svg?branch=main
[cov-link]: https://coveralls.io/github/ddmms/pack-mm?branch=main
[license-badge]: https://img.shields.io/badge/License-MIT-yellow.svg
[license-link]: https://opensource.org/license/MIT
